@@ -1,4 +1,8 @@
 `print.PedMap` <- function(x, n=6, m=6, ...){
+# Correct for too large n and m
+  nm <- dim(x$genotypes)
+  n <- min(n,nm[1])
+  m <- min(m,nm[2])
   
   cat("First",n,"rows and",m,"columns of $genotypes:\n")
   print(x$genotypes[1:n,x$map$snp.names[1:m], with=FALSE])
